@@ -16,16 +16,16 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, Type, Union
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import SortOrderType
 from .paginator import ListHumanLoopsPaginator
 from .type_defs import (
-    DescribeHumanLoopResponseResponseTypeDef,
+    DescribeHumanLoopResponseTypeDef,
     HumanLoopDataAttributesTypeDef,
     HumanLoopInputTypeDef,
-    ListHumanLoopsResponseResponseTypeDef,
-    StartHumanLoopResponseResponseTypeDef,
+    ListHumanLoopsResponseTypeDef,
+    StartHumanLoopResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -55,20 +55,25 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class AugmentedAIRuntimeClient:
+class AugmentedAIRuntimeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        AugmentedAIRuntimeClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/client.html#can_paginate)
         """
 
@@ -76,17 +81,15 @@ class AugmentedAIRuntimeClient:
         """
         Deletes the specified human loop for a flow definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.delete_human_loop)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.delete_human_loop)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/client.html#delete_human_loop)
         """
 
-    def describe_human_loop(
-        self, *, HumanLoopName: str
-    ) -> DescribeHumanLoopResponseResponseTypeDef:
+    def describe_human_loop(self, *, HumanLoopName: str) -> DescribeHumanLoopResponseTypeDef:
         """
         Returns information about the specified human loop.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.describe_human_loop)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.describe_human_loop)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/client.html#describe_human_loop)
         """
 
@@ -100,7 +103,7 @@ class AugmentedAIRuntimeClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/client.html#generate_presigned_url)
         """
 
@@ -113,11 +116,11 @@ class AugmentedAIRuntimeClient:
         SortOrder: SortOrderType = None,
         NextToken: str = None,
         MaxResults: int = None
-    ) -> ListHumanLoopsResponseResponseTypeDef:
+    ) -> ListHumanLoopsResponseTypeDef:
         """
         Returns information about human loops, given the specified parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.list_human_loops)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.list_human_loops)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/client.html#list_human_loops)
         """
 
@@ -128,11 +131,11 @@ class AugmentedAIRuntimeClient:
         FlowDefinitionArn: str,
         HumanLoopInput: "HumanLoopInputTypeDef",
         DataAttributes: "HumanLoopDataAttributesTypeDef" = None
-    ) -> StartHumanLoopResponseResponseTypeDef:
+    ) -> StartHumanLoopResponseTypeDef:
         """
         Starts a human loop, provided that at least one activation condition is met.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.start_human_loop)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.start_human_loop)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/client.html#start_human_loop)
         """
 
@@ -140,12 +143,12 @@ class AugmentedAIRuntimeClient:
         """
         Stops the specified human loop.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/client.html#stop_human_loop)
         """
 
     def get_paginator(self, operation_name: Literal["list_human_loops"]) -> ListHumanLoopsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
         """
