@@ -24,14 +24,14 @@ from typing import Iterator, Union
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import SortOrderType
-from .type_defs import ListHumanLoopsResponseResponseTypeDef, PaginatorConfigTypeDef
+from .type_defs import ListHumanLoopsResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListHumanLoopsPaginator",)
 
 
 class ListHumanLoopsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
     """
 
@@ -43,8 +43,8 @@ class ListHumanLoopsPaginator(Boto3Paginator):
         CreationTimeBefore: Union[datetime, str] = None,
         SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListHumanLoopsResponseResponseTypeDef]:
+    ) -> Iterator[ListHumanLoopsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
         """
